@@ -245,7 +245,7 @@ class RestAPI(object):
 				return r3sponse.success_response("Successfully found the uid for the specified api key.", {"uid":uid})
 		return r3sponse.error_response("Failed to find the uid for the specified api key.")
 	def get_subscriptions(self):
-		#try:
+		try:
 
 			# iterate.
 			subscriptions = {}
@@ -263,7 +263,7 @@ class RestAPI(object):
 				for subscription_plan in subscription_plans:
 					id = subscription_plan['plan']['id']
 					try: subscriptions[email]["plans"][id]
-					except KeyError: subscriptions[email][email]["plans"][id] = {}
+					except KeyError: subscriptions[email]["plans"][id] = {}
 					subscriptions[email]["plans"][id]["subscription_id"] = subscription_plan['id'],
 					subscriptions[email]["plans"][id]["plan_id"] = subscription_plan['plan']['id'],
 					subscriptions[email]["plans"][id]["plan_nickname"] = subscription_plan['plan']['nickname'],
@@ -275,8 +275,8 @@ class RestAPI(object):
 			})
 
 		# error.
-		#except Exception as e:
-		#	return r3sponse.error_response(f"Failed to retrieve the subscriptions, error: {e}.")
+		except Exception as e:
+			return r3sponse.error_response(f"Failed to retrieve the subscriptions, error: {e}.")
 
 		#
 	def create_subscription(self):
